#!/usr/bin/env python

class FileExistResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually."""


    def __init__(self):
        """
        Attributes:
          swaggerTypes (dict): The key is attribute name and the value is attribute type.
          attributeMap (dict): The key is attribute name and the value is json key in definition.
        """
        self.swaggerTypes = {
            'FileExist': 'FileExist',
            'Code': 'int',
            'Status': 'str'

        }

        self.attributeMap = {
            'FileExist': 'FileExist','Code': 'Code','Status': 'Status'}       

        self.FileExist = None # FileExist
        self.Code = None # int
        self.Status = None # str
        
