#!/usr/bin/env python

class DateTime(object):
    """NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually."""


    def __init__(self):
        """
        Attributes:
          swaggerTypes (dict): The key is attribute name and the value is attribute type.
          attributeMap (dict): The key is attribute name and the value is json key in definition.
        """
        self.swaggerTypes = {
            'Year': 'int',
            'Month': 'int',
            'Day': 'int',
            'Hour': 'int',
            'Minute': 'int',
            'Second': 'int',
            'Millisecond': 'int',
            'DayOfWeek': 'str',
            'DayOfYear': 'int',
            'Kind': 'str',
            'Ticks': 'long',
            'TimeOfDay': 'str'

        }

        self.attributeMap = {
            'Year': 'Year','Month': 'Month','Day': 'Day','Hour': 'Hour','Minute': 'Minute','Second': 'Second','Millisecond': 'Millisecond','DayOfWeek': 'DayOfWeek','DayOfYear': 'DayOfYear','Kind': 'Kind','Ticks': 'Ticks','TimeOfDay': 'TimeOfDay'}       

        self.Year = None # int
        self.Month = None # int
        self.Day = None # int
        self.Hour = None # int
        self.Minute = None # int
        self.Second = None # int
        self.Millisecond = None # int
        self.DayOfWeek = None # str
        self.DayOfYear = None # int
        self.Kind = None # str
        self.Ticks = None # long
        self.TimeOfDay = None # str
        
