__author__ = 'farooq.sheikh'

from setuptools import setup, find_packages

setup(
    name = 'asposestoragecloud',
    packages = find_packages(),
    version = '1.0.0',
    description = 'Aspose.Storage Cloud SDK for Python allows you to use Aspose.Storage API in your Python applications',
    author='Farooq Sheikh',
    author_email='farooq.sheikh@aspose.com',
    url='https://github.com/asposetotal/Aspose_Total_Cloud/tree/master/SDKs/Aspose.Storage_Cloud_SDK_For_Python',
    classifiers=[
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent'
    ]
)
