#!/usr/bin/env python

class FileDetail(object):
    """NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually."""


    def __init__(self):
        """
        Attributes:
          swaggerTypes (dict): The key is attribute name and the value is attribute type.
          attributeMap (dict): The key is attribute name and the value is json key in definition.
        """
        self.swaggerTypes = {
            'Name': 'str',
            'IsFolder': 'bool',
            'ModifiedDate': 'DateTime',
            'Size': 'long',
            'Path': 'str'

        }

        self.attributeMap = {
            'Name': 'Name','IsFolder': 'IsFolder','ModifiedDate': 'ModifiedDate','Size': 'Size','Path': 'Path'}

        self.Name = None # str
        self.IsFolder = None # bool
        self.ModifiedDate = None # DateTime
        self.Size = None # long
        self.Path = None # str
        
